@@ -11,7 +11,6 @@ import json
 
 from tuxbake.argparse import setup_parser
 from tuxbake.build import build
-from tuxbake.models import OEBuild
 
 
 ##############
@@ -28,6 +27,11 @@ def main() -> int:
             build_dir=options.build_dir_name,
             local_manifest=options.local_manifest,
             pinned_manifest=options.pinned_manifest,
+            runtime=options.runtime,
+            image=options.image,
+            debug=options.debug,
+            build_only=options.build_only,
+            sync_only=options.sync_only,
         )
 
 
@@ -35,4 +39,5 @@ def start():
     if __name__ == "__main__":
         sys.exit(main())
 
+
 start()
