@@ -6,11 +6,14 @@
 #
 # SPDX-License-Identifier: MIT
 
-from tuxbake.argparse import setup_parser
 from tuxbake.models import OEBuild
 from tuxmake.runtime import Terminated
 import signal
-import json
+from tuxbake.exceptions import (
+    TuxbakeParsingError,
+    TuxbakeRunCmdError,
+)
+import sys
 
 
 def build(**kwargs):
@@ -22,6 +25,10 @@ def build(**kwargs):
         oebuild.do_build()
     except (KeyboardInterrupt, Terminated) as ex:
         print("tuxbake Interrupted")
+    except (TuxbakeParsingError, TuxbakeRunCmdError) as ex:
+        sys.stderr.write(f"{str(ex)}\n")
+        sys.exit(1)
+
     oebuild.do_cleanup()
     signal.signal(signal.SIGTERM, old_sigterm)
     return oebuild
